@@ -5,6 +5,22 @@ from itertools import ( product,
 
 log = logging.getLogger(__name__)
 
+class ParsedDate:
+    """
+    DateParser object
+    """
+    separators      = []
+    original_string = ''
+    data            = {}
+    alldata         = {}
+    formatting      = ''
+    format_list     = []
+    dateObject      = None
+    isValid         = False
+
+    def __init__(self):
+        self.created = dt.now().timestamp()
+
 class DateData(dict):
     """
     DateParser data class
@@ -168,7 +184,7 @@ class DateParser(DateData):
     """
 
     def __init__(self):
-        self.__setVars()
+        self.date = ParsedDate()
         super().__init__()
 
     def date_split(self, DATE):
@@ -182,15 +198,15 @@ class DateParser(DateData):
         c = 0
         for i in split_date:
             if re.match( self['match sep'], str(i), flags = re.IGNORECASE ):
-                self.data[c] = str(i)
-                self.alldata[c] = self.data[c]
+                self.date.data[c] = str(i)
+                self.date.alldata[c] = self.date.data[c]
             else:
-                self.alldata[c] = str(i)
-                self.separators.append(str(i))
+                self.date.alldata[c] = str(i)
+                self.date.separators.append(str(i))
 
             c += 1
 
-        return ( self.data, self.alldata )
+        return ( self.date.data, self.date.alldata )
 
     def __parse_nums(self, numstr):
         numstr = str(numstr)
@@ -410,8 +426,8 @@ class DateParser(DateData):
 
             return None
 
-        self.__setVars()
-        self.original_string = str_
+        self.date = ParsedDate()
+        self.date.original_string = str_
 
         log.debug("Trying entire string with full date formats")
 
@@ -424,19 +440,19 @@ class DateParser(DateData):
                     break
 
                 log.debug(f"String matches datetime object - date is VALID")
-                self.isValid = True
-                self.alldata = [ str_ ]
-                self.dateObject = dt.strptime( str_, i[1] )
-                self.formatting = i[1]
-                return self.formatting
+                self.date.isValid = True
+                self.date.alldata = [ str_ ]
+                self.date.dateObject = dt.strptime( str_, i[1] )
+                self.date.formatting = i[1]
+                return self.date
 
         log.debug(f"Attempting to split the string and trying each individual piece of data")
         self.date_split( str_ )
         data_matches = {}
 
         change_data, pastnum = [], None
-        for i in self.data:
-            num = chk_spelled(self['spelled'], self.data[i])
+        for i in self.date.data:
+            num = chk_spelled(self['spelled'], self.date.data[i])
 
             if pastnum:
                 try:
@@ -457,14 +473,14 @@ class DateParser(DateData):
                 pass
 
         for CH in change_data:
-            self.data[ CH[0] ] = CH[1]
-            self.alldata[ CH[0] ] = CH[1]
+            self.date.data[ CH[0] ] = CH[1]
+            self.date.alldata[ CH[0] ] = CH[1]
             if CH[2]:
-                self.data[ CH[2] ] = ''
-                self.alldata[ CH[2] ] = ''
+                self.date.data[ CH[2] ] = ''
+                self.date.alldata[ CH[2] ] = ''
 
-        for i in self.data:
-            DN = self.data[i]
+        for i in self.date.data:
+            DN = self.date.data[i]
             data_matches[DN] = []
 
             if re.match( '^[0-9]+$', DN ):
@@ -474,8 +490,8 @@ class DateParser(DateData):
 
             else:
                 for F in self['format codes']['single']:
-                    if re.match( F[0], self.data[i], flags = re.IGNORECASE ):
-                        log.debug(f"Found a match for {self.data[i]} - adding {F[1]} to list of possibilities")
+                    if re.match( F[0], self.date.data[i], flags = re.IGNORECASE ):
+                        log.debug(f"Found a match for {self.date.data[i]} - adding {F[1]} to list of possibilities")
                         data_matches[DN].append( F[1] )
 
         list_ = []
@@ -491,7 +507,7 @@ class DateParser(DateData):
 
             combos.append(i)
 
-        log.debug(f"self.data = {str(self.data)}")
+        log.debug(f"self.date.data = {str(self.date.data)}")
         for i in combos:
             log.debug(f"Combo = {str(i)}")
             code_len = 0
@@ -598,25 +614,25 @@ class DateParser(DateData):
             fmt   = []
             alldata = []
             chk_str = []
-            for c in range( 0, len( self.alldata )):
-                if c in self.data:
+            for c in range( 0, len( self.date.alldata )):
+                if c in self.date.data:
                     fmt.append( str(i[count]) )
                     count += 1
 
-                    if fmt[c] in ('%d', '%m', '%H', '%I', '%M', '%S') and re.match( '^[0-9]{1}$', str(self.alldata[c]) ):
-                        log.debug(f"Changing date/time data to 2 digits instead of one - ({fmt[c]}) ({self.alldata[c]})")
-                        alldata.append( '0' + str(self.alldata[c]) )
+                    if fmt[c] in ('%d', '%m', '%H', '%I', '%M', '%S') and re.match( '^[0-9]{1}$', str(self.date.alldata[c]) ):
+                        log.debug(f"Changing date/time data to 2 digits instead of one - ({fmt[c]}) ({self.date.alldata[c]})")
+                        alldata.append( '0' + str(self.date.alldata[c]) )
 
-                    elif self.alldata[c].lower() in ('am,', 'pm'):
+                    elif self.date.alldata[c].lower() in ('am,', 'pm'):
                         log.debug(f"Changing am/pm data to uppercase")
-                        alldata.append( self.alldata[c].upper() )
+                        alldata.append( self.date.alldata[c].upper() )
 
                     else:
-                        alldata.append( str(self.alldata[c]) )
+                        alldata.append( str(self.date.alldata[c]) )
 
                 else:
-                    fmt.append( str(self.alldata[c]) )
-                    alldata.append( str(self.alldata[c]) )
+                    fmt.append( str(self.date.alldata[c]) )
+                    alldata.append( str(self.date.alldata[c]) )
 
 
             log.debug(f"Alldata = {str(fmt)}")
@@ -629,33 +645,33 @@ class DateParser(DateData):
 
                 log.debug(f"Checking if datetime.strftime({formatting}) matches {str_}")
                 if DObj.strftime( formatting ) == ''.join(alldata):
-                    self.isValid = True
+                    self.date.isValid = True
 
-                    self.format_list.append(formatting)
+                    self.date.format_list.append(formatting)
 
-                    self.alldata = alldata
-                    self.dateObject = DObj
-                    self.formatting = formatting
+                    self.date.alldata = alldata
+                    self.date.dateObject = DObj
+                    self.date.formatting = formatting
                     log.debug(f"String matches datetime object - date is VALID")
-                    return self
+                    return self.date
                 else:
                     log.debug(f"String does not match datetime object - date is INVALID")
-                    self.isValid = False
-                    if self.formatting:
+                    self.date.isValid = False
+                    if self.date.formatting:
                         continue
 
-                    self.alldata = alldata
-                    self.dateObject = DObj
-                    self.formatting = formatting
+                    self.date.alldata = alldata
+                    self.date.dateObject = DObj
+                    self.date.formatting = formatting
 
-        if not self.formatting:
+        if not self.date.formatting:
             try:
                 if re.match( '^-?[0-9]+$', str_ ):
                     log.debug("Formatting cannot be found - trying timestamp")
                     x = dt.fromtimestamp(int( str_ ))
-                    self.dateObject = x
+                    self.date.dateObject = x
                     log.warning("Time is given as timestamp - formatting will be None")
-                    self.formatting = ''
+                    self.date.formatting = ''
                 else:
                     raise ValueError
             except ValueError:
@@ -663,19 +679,19 @@ class DateParser(DateData):
             except Exception as E:
                 log.exception(E)
             finally:
-                return self
+                return self.date
 
-        return self
+        return self.date
 
-    def __setVars(self):
-        self.separators      = []
-        self.original_string = ''
-        self.data            = {}
-        self.alldata         = {}
-        self.formatting      = ''
-        self.format_list     = []
-        self.dateObject      = None
-        self.isValid         = False
+    # def __setVars(self):
+    #     self.date.separators      = []
+    #     self.date.original_string = ''
+    #     self.date.data            = {}
+    #     self.date.alldata         = {}
+    #     self.date.formatting      = ''
+    #     self.date.format_list     = []
+    #     self.date.dateObject      = None
+    #     self.date.isValid         = False
 
     @staticmethod
     def try_fmt(str_, fmt):
